"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FieldButton = FieldButton;
exports.OutlineButton = OutlineButton;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _style = require("../style");
var _Touchable = require("./Touchable");
var _Text = require("./Text");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 * @typedef {Object} Props
 * @property {JSX.Element} children custom view children
 * @property {() => void} onPress will be invoke when click
 * @property {import('react-native').ViewStyle} textStyle Custom style for content
 * @property {string} testID testID for each component
 * @property {boolean} disabled props for active or disable button
 * @property {string} isUseBackground effect style when button is clicked
 * @property {string} rippleColor effect style color when button is clicked
 * @property {object} hitSlop handle area clicked button
 * @property {string} textColor style color text
 * @property {string} textButton text for button
 * @property {string} icon source for icon button
 * @property {number} iconSize size of icon button
 * @property {number} textSize size of text button
 */

function FieldButton(_ref) {
  let {
    textColor = _style.Colors.WHITE,
    textButton = 'Button',
    backgroundColor = _style.Colors.AQUA,
    style,
    onPress,
    testID,
    disabled = false,
    icon,
    iconSize = 20,
    textSize = 14,
    textStyle,
    typeText = 'regular'
  } = _ref;
  return /*#__PURE__*/_react.default.createElement(_Touchable.Touchable, {
    testID: testID,
    onPress: onPress,
    disabled: disabled,
    style: [styles.container, {
      backgroundColor
    }, styles.rowStyle, _reactNative.Platform.OS === 'ios' && styles.bottomWithPadding, style]
  }, !icon ? null : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: icon,
    resizeMode: "contain",
    style: [styles.iconStyle, {
      width: iconSize,
      height: iconSize
    }]
  }), typeText === 'bold' ? /*#__PURE__*/_react.default.createElement(_Text.TextBold, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }) : typeText === 'medium' ? /*#__PURE__*/_react.default.createElement(_Text.TextMedium, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }) : /*#__PURE__*/_react.default.createElement(_Text.TextRegular, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }));
}
function OutlineButton(_ref2) {
  let {
    textColor = _style.Colors.BLACK,
    textButton = 'Button',
    backgroundColor = _style.Colors.WHITE,
    borderColor = _style.Colors.BLACK,
    style,
    onPress,
    testID,
    icon,
    textStyle,
    iconSize = 20,
    disabled = false,
    typeText = 'regular',
    textSize = 14
  } = _ref2;
  return /*#__PURE__*/_react.default.createElement(_Touchable.Touchable, {
    onPress: onPress,
    testID: testID,
    disabled: disabled,
    style: [styles.container, styles.outline, {
      backgroundColor,
      borderColor
    }, styles.rowStyle, _reactNative.Platform.OS === 'ios' && styles.bottomWithPadding, style]
  }, !icon ? null : /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: icon,
    resizeMode: "contain",
    style: [styles.iconStyle, {
      width: iconSize,
      height: iconSize
    }]
  }), typeText === 'bold' ? /*#__PURE__*/_react.default.createElement(_Text.TextBold, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }) : typeText === 'medium' ? /*#__PURE__*/_react.default.createElement(_Text.TextMedium, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }) : /*#__PURE__*/_react.default.createElement(_Text.TextRegular, {
    size: textSize,
    style: textStyle,
    color: textColor,
    text: textButton
  }));
}
const styles = _reactNative.StyleSheet.create({
  container: {
    backgroundColor: _style.Colors.AQUA,
    padding: 10,
    width: '100%',
    alignSelf: 'flex-start',
    borderRadius: 6,
    alignItems: 'center',
    justifyContent: 'center'
  },
  outline: {
    borderWidth: 1,
    borderColor: _style.Colors.AQUA
  },
  rowStyle: {
    flexDirection: 'row'
  },
  iconStyle: {
    marginRight: 4
  },
  bottomWithPadding: {
    paddingBottom: 7
  }
});
//# sourceMappingURL=Button.js.map