"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _TextBold = _interopRequireDefault(require("./TextBold"));
var _TextMedium = _interopRequireDefault(require("./TextMedium"));
var _TextRegular = _interopRequireDefault(require("./TextRegular"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/**
 *
 * @property {string} title title of header
 * @property {string} titleColor color of title header
 * @property {string} titleTextType type title header, bold, regular or medium text
 * @property {boolean} iconBack display icon back or not
 * @property {object} iconBackStyle custome style for icon back
 * @property {() => void} iconBackOnPress will be invoke when click icon back
 * @property {string} iconRight path for icon right
 * @property {object} iconRightStyle custome style for icon right
 * @property {() => void} iconRightOnPress will be invoke when click icon right
 * @property {JSX.Element} viewRight custom view for right side header
 * @property {object} containerStyle custome style for container header
 * @property {number} titleSize size of title header
 */

const Header = _ref => {
  let {
    titleHeader,
    titleSize = 14,
    titleColor = '#000',
    titleTextType = 'regular',
    iconBack = true,
    iconBackStyle,
    iconBackOnPress,
    iconRight,
    iconRightStyle,
    iconRightOnPress,
    viewRight = null,
    containerStyle
  } = _ref;
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.container, containerStyle]
  }, iconBack && /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: require('../assets/icons/akusign_logo.png'),
    style: styles.logoApp
  }), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.rowHead
  }, iconBack ? /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 0.8,
    style: [styles.widthView, iconBackStyle, styles.start],
    onPress: iconBackOnPress
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: require('../assets/icons/arrow_back_ic.png'),
    style: [styles.logoApp, iconBackStyle]
  })) : /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.width10
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: require('../assets/icons/akusign_logo.png'),
    style: styles.logoApp
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.widthView, styles.width80]
  }, titleTextType === 'regular' ? /*#__PURE__*/_react.default.createElement(_TextRegular.default, {
    text: titleHeader,
    color: titleColor,
    size: titleSize
  }) : titleTextType === 'medium' ? /*#__PURE__*/_react.default.createElement(_TextMedium.default, {
    text: titleHeader,
    color: titleColor,
    size: titleSize
  }) : /*#__PURE__*/_react.default.createElement(_TextBold.default, {
    text: titleHeader,
    color: titleColor,
    size: titleSize
  })), /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.widthView
  }, viewRight ? viewRight : /*#__PURE__*/_react.default.createElement(_reactNative.TouchableOpacity, {
    activeOpacity: 0.8,
    style: styles.widthView,
    onPress: iconRightOnPress,
    disabled: iconRight ? false : true
  }, /*#__PURE__*/_react.default.createElement(_reactNative.Image, {
    source: iconRight,
    style: [styles.logoApp, iconRightStyle]
  })))));
};
const styles = _reactNative.StyleSheet.create({
  width80: {
    width: '80%'
  },
  width10: {
    width: '10%'
  },
  start: {
    justifyContent: 'flex-start',
    alignItems: 'flex-start'
  },
  rowHead: {
    width: '100%',
    flexDirection: 'row',
    alignItems: 'center'
  },
  container: {
    width: '100%',
    backgroundColor: '#fff',
    paddingHorizontal: 15
  },
  widthView: {
    width: '10%',
    justifyContent: 'center',
    alignItems: 'center'
  },
  logoApp: {
    width: 50,
    height: 50,
    resizeMode: 'contain'
  }
});
var _default = exports.default = Header;
//# sourceMappingURL=Header.js.map