import React from 'react';
import { StyleSheet, Text } from 'react-native';

/**
 * @property {string} text text to display
 * @property {number} numberOfLines display text with how many lines
 * @property {object} onTextLayout object is returned in the callback as a result of a component layout change
 * @property {number} size size of text
 * @property {string} color color of text
 * @property {number} lineHeight space for text
 * @property {import('react-native').ViewStyle} style style for text
 * @property {string} testID testID for each component
 */

export const TextRegular = _ref => {
  let {
    text,
    numberOfLines,
    onTextLayout,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [styles.regularText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    onTextLayout: onTextLayout,
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const TextMedium = _ref2 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref2;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [styles.mediumText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const TextSemiBold = _ref3 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref3;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [styles.semiBoldText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const TextBold = _ref4 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref4;
  return /*#__PURE__*/React.createElement(Text, {
    style: [styles.boldText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    ellipsizeMode: "tail",
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const TextExtraBold = _ref5 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref5;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [styles.extraBoldText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const TextLight = _ref6 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    testID = ''
  } = _ref6;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [styles.lightText, {
      fontSize: size,
      color: color,
      lineHeight: lineHeight
    }, style],
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
export const CustomText = _ref7 => {
  let {
    text,
    numberOfLines,
    size = 14,
    color,
    lineHeight = size * 1.5,
    style,
    fontFamily,
    testID = ''
  } = _ref7;
  return /*#__PURE__*/React.createElement(Text, {
    ellipsizeMode: "tail",
    style: [{
      fontSize: size,
      color: color,
      lineHeight: lineHeight,
      fontFamily: fontFamily
    }, style],
    numberOfLines: numberOfLines,
    accessible: true,
    accessibilityLabel: testID,
    testID: testID
  }, text);
};
const styles = StyleSheet.create({
  extraBoldText: {
    fontWeight: 'bold',
    color: '#000'
  },
  boldText: {
    fontWeight: '800',
    color: '#000'
  },
  semiBoldText: {
    fontWeight: '600',
    color: '#000'
  },
  mediumText: {
    fontWeight: '400',
    color: '#000'
  },
  regularText: {
    fontWeight: 'normal',
    color: '#000'
  },
  lightText: {
    fontWeight: '200',
    color: '#000'
  }
});
//# sourceMappingURL=Text.js.map