import React from 'react';
import { View, Image, TouchableOpacity, StyleSheet } from 'react-native';
import TextBold from './TextBold';
import TextMedium from './TextMedium';
import TextRegular from './TextRegular';

/**
 *
 * @property {string} title title of header
 * @property {string} titleColor color of title header
 * @property {string} titleTextType type title header, bold, regular or medium text
 * @property {boolean} iconBack display icon back or not
 * @property {object} iconBackStyle custome style for icon back
 * @property {() => void} iconBackOnPress will be invoke when click icon back
 * @property {string} iconRight path for icon right
 * @property {object} iconRightStyle custome style for icon right
 * @property {() => void} iconRightOnPress will be invoke when click icon right
 * @property {JSX.Element} viewRight custom view for right side header
 * @property {object} containerStyle custome style for container header
 * @property {number} titleSize size of title header
 */

interface props {
  titleHeader: string;
  titleSize: number;
  titleColor: string;
  titleTextType: string;
  iconBack: boolean;
  iconBackStyle: any;
  iconBackOnPress: () => void;
  iconRight: any;
  iconRightStyle: any;
  iconRightOnPress: () => void;
  viewRight: any;
  containerStyle: any;
}

const Header = ({
  titleHeader,
  titleSize = 14,
  titleColor = '#000',
  titleTextType = 'regular',
  iconBack = true,
  iconBackStyle,
  iconBackOnPress,
  iconRight,
  iconRightStyle,
  iconRightOnPress,
  viewRight = null,
  containerStyle,
}: props) => {
  return (
    <View style={[styles.container, containerStyle]}>
      {iconBack && (
        <Image
          source={require('../assets/icons/akusign_logo.png')}
          style={styles.logoApp}
        />
      )}
      <View style={styles.rowHead}>
        {iconBack ? (
          <TouchableOpacity
            activeOpacity={0.8}
            style={[styles.widthView, iconBackStyle, styles.start]}
            onPress={iconBackOnPress}
          >
            <Image
              source={require('../assets/icons/arrow_back_ic.png')}
              style={[styles.logoApp, iconBackStyle]}
            />
          </TouchableOpacity>
        ) : (
          <View style={styles.width10}>
            <Image
              source={require('../assets/icons/akusign_logo.png')}
              style={styles.logoApp}
            />
          </View>
        )}
        <View style={[styles.widthView, styles.width80]}>
          {titleTextType === 'regular' ? (
            <TextRegular
              text={titleHeader}
              color={titleColor}
              size={titleSize}
            />
          ) : titleTextType === 'medium' ? (
            <TextMedium
              text={titleHeader}
              color={titleColor}
              size={titleSize}
            />
          ) : (
            <TextBold text={titleHeader} color={titleColor} size={titleSize} />
          )}
        </View>
        <View style={styles.widthView}>
          {viewRight ? (
            viewRight
          ) : (
            <TouchableOpacity
              activeOpacity={0.8}
              style={styles.widthView}
              onPress={iconRightOnPress}
              disabled={iconRight ? false : true}
            >
              <Image
                source={iconRight}
                style={[styles.logoApp, iconRightStyle]}
              />
            </TouchableOpacity>
          )}
        </View>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({
  width80: {
    width: '80%',
  },
  width10: {
    width: '10%',
  },
  start: {
    justifyContent: 'flex-start',
    alignItems: 'flex-start',
  },
  rowHead: {
    width: '100%',
    flexDirection: 'row',
    alignItems: 'center',
  },
  container: {
    width: '100%',
    backgroundColor: '#fff',
    paddingHorizontal: 15,
  },
  widthView: {
    width: '10%',
    justifyContent: 'center',
    alignItems: 'center',
  },
  logoApp: {
    width: 50,
    height: 50,
    resizeMode: 'contain',
  },
});
export default Header;
