import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { Modal, View, StyleSheet } from 'react-native';
import { Shadow } from '../style';

const ModalBottom = forwardRef((props, ref) => {
  const [isVisible, setIsVisible] = useState(false);
  useImperativeHandle(ref, () => {
    return {
      show: () => setIsVisible(true),
      hide: () => setIsVisible(false),
    };
  });
  return (
    <Modal transparent visible={isVisible} animationType="slide">
      <View style={styles.container}>
        <View style={[styles.content, Shadow.Top]}>{props.children}</View>
      </View>
    </Modal>
  );
});

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: 'rgba(0,0,0,0.1)',
    justifyContent: 'flex-end',
    alignItems: 'flex-end',
  },
  content: {
    width: '100%',
    backgroundColor: '#fff',
    borderRadius: 6,
    borderColor: '#dedede',
    borderWidth: 1,
  },
});

export default ModalBottom;
