import React, { forwardRef, useImperativeHandle, useState } from 'react';
import { Modal, StyleSheet, View } from 'react-native';

const ModalCenter = forwardRef((props, ref) => {
  const [isVisible, setIsVisible] = useState(false);
  useImperativeHandle(ref, () => {
    return {
      show: () => setIsVisible(true),
      hide: () => setIsVisible(false),
    };
  });
  return (
    <Modal transparent visible={isVisible} animationType="slide">
      <View style={styles.container}>
        <View style={styles.content}>{props.children}</View>
      </View>
    </Modal>
  );
});

const styles = StyleSheet.create({
  content: {
    width: '90%',
    backgroundColor: '#fff',
    borderRadius: 6,
  },
  container: {
    flex: 1,
    backgroundColor: 'rgba(0,0,0,0.4)',
    justifyContent: 'center',
    alignItems: 'center',
  },
});

export default ModalCenter;
