import React from 'react';
import { TouchableOpacity } from 'react-native';

/**
 * @property {JSX.Element} children custom view for child
 * @property {() => void} onPress will be invoke when click component
 * @property {boolean} disabled disabled button or not
 * @property {object} style custome style for component
 * @property {string} testID test id for automation test
 */

interface props {
  children: any;
  onPress: () => void;
  disabled: boolean;
  style: object;
  testID: string;
}

export const Touchable = ({
  children,
  onPress,
  disabled,
  style,
  testID,
}: props) => {
  return (
    <TouchableOpacity
      accessible={true}
      accessibilityLabel={testID}
      testID={testID}
      style={style}
      activeOpacity={0.8}
      onPress={onPress}
      disabled={disabled}
    >
      {children}
    </TouchableOpacity>
  );
};
